#!perl
use 5.006;
use strict;
use warnings FATAL => 'all';
use Test::More 0.82;
eval 'use Test::Signature';
plan skip_all => 'Test::Signature required for this test' if $@;
plan tests    => 1;
signature_ok();
